@@ -1555,6 +1555,49 @@ class PlaceService(BaseRdbmsService):
 
             return places_contacts
 
+    def index_all_places(self, connection=None):
+
+        """
+        Reindex all the places
+
+
+        :note: This function MUST NOT be surfaced to any client applications,
+            but called from Python terminal as follows:
+
+            ```bash
+            $ python
+            Python 3.7.4 (default, Jul 12 2019, 18:26:19)
+            [GCC 5.4.0 20160609] on linux
+            Type "help", "copyright", "credits" or "license" for more information.
+            >>> from majormode.mercurius.service.place.place_service import PlaceService
+            >>> PlaceService().index_all_places()
+            ```
+
+        :todo: This function SHOULD be replaced with the use of another
+            technology such as Elasticsearch more suitable for indexing and
+            indexing data.
+
+
+        :param connection: An object `RdbmsConnection` with auto commit.
+        """
+        with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
+            cursor = connection.execute(
+                """
+                SELECT
+                    account_id
+                  FROM ONLY
+                    place
+                """
+            )
+
+            place_ids = [
+                row.get_value('place_id', cast.string_to_uuid)
+                for row in cursor.fetch_all()
+            ]
+
+            for place_id in place_ids:
+                self.__index_place(place_id, connection=connection)
+
     def search_places(
             self,
             account_id: uuid.UUID = None,
